Enum WriteStyle

enum WriteStyle

Whether or not to print styles to the target.

Variants

Auto

Try to print styles, but don't force the issue.

Always

Try very hard to print styles.

Never

Never print styles.

Implementations

impl Clone for WriteStyle

fn clone(self: &Self) -> WriteStyle

impl Copy for WriteStyle

impl Debug for WriteStyle

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for WriteStyle

fn default() -> WriteStyle

impl Eq for WriteStyle

impl Freeze for WriteStyle

impl From for WriteStyle

fn from(choice: ColorChoice) -> Self

impl Hash for WriteStyle

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for WriteStyle

fn eq(self: &Self, other: &WriteStyle) -> bool

impl RefUnwindSafe for WriteStyle

impl Send for WriteStyle

impl StructuralPartialEq for WriteStyle

impl Sync for WriteStyle

impl Unpin for WriteStyle

impl UnsafeUnpin for WriteStyle

impl UnwindSafe for WriteStyle

impl<T> Any for WriteStyle

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for WriteStyle

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for WriteStyle

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for WriteStyle

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for WriteStyle

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for WriteStyle

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for WriteStyle

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for WriteStyle

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for WriteStyle

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>