Struct Timestamp

struct Timestamp { ... }

An RFC3339 formatted timestamp.

The timestamp implements Display and can be written to a Formatter.

Implementations

impl Debug for Timestamp

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Timestamp

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Timestamp

impl RefUnwindSafe for Timestamp

impl Send for Timestamp

impl Sync for Timestamp

impl Unpin for Timestamp

impl UnsafeUnpin for Timestamp

impl UnwindSafe for Timestamp

impl<T> Any for Timestamp

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Timestamp

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Timestamp

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Timestamp

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for Timestamp

fn to_string(self: &Self) -> String

impl<T, U> Into for Timestamp

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Timestamp

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Timestamp

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>