Enum Target
enum Target
Log target, either stdout, stderr or a custom pipe.
Variants
-
Stdout Logs will be sent to standard output.
-
Stderr Logs will be sent to standard error.
-
Pipe(Box<dyn std::io::Write + Send + 'static>) Logs will be sent to a custom pipe.
Implementations
impl Debug for Target
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Target
fn default() -> Target
impl Freeze for Target
impl RefUnwindSafe for Target
impl Send for Target
impl Sync for Target
impl Unpin for Target
impl UnsafeUnpin for Target
impl UnwindSafe for Target
impl<T> Any for Target
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Target
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Target
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Target
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Target
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Target
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Target
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>